@@ -697,7 +697,7 @@ class RedshiftDialectMixin(object):
         if isinstance(column_info['type'], VARCHAR):
             if column_info['type'].length is None:
                 column_info['type'] = NullType()
-        if re.match('(?:.*)(char)(?:.*)', column_info['raw_data_type']):
+        if re.match('char', column_info['raw_data_type']):
             column_info['type'] = CHAR
 
         if 'info' not in column_info:
